==> mktcenter-service-1.0.2-vg-20220525.073555-2-sources.jar: com/bizvane/mktcenterservice/models/bo/TaskWXBO.java <==
package com.bizvane.mktcenterservice.models.bo;
import org.springframework.format.annotation.DateTimeFormat;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
/**
 * @Author: lijunwei
 * @Time: 2018/8/15 10:20
 */
public class TaskWXBO {
    private  Long taskId;
    private String   taskCode ;
    private String taskName ;
    private Integer  taskType ;
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            locale = "zh",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd"
    )
    private Date startTime;
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            locale = "zh",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd"
    )
    private Date   endTime;
    private Integer  rewarded;  // 1=已完成  0未完成
    private String  taskProgress; //进度
    private Integer sourceType;//1=线下   2=线上
    private Integer mbrConditionType;
    private String mbrCondition;
    private String templateCode;//问卷调查模板code

    private Long sysCompanyId;

    private Long sysBrandId;

    //门店限制状态：0不限制，1限制
    private Boolean isStoreLimit;

    //白名单店铺list
    private String storeLimitList;

    public Long getTaskId() {
        return taskId;
    }

    public void setTaskId(Long taskId) {
        this.taskId = taskId;
    }

    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public Integer getTaskType() {
        return taskType;
    }

    public void setTaskType(Integer taskType) {
        this.taskType = taskType;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getRewarded() {
        return rewarded;
    }

    public void setRewarded(Integer rewarded) {
        this.rewarded = rewarded;
    }

    public String getTaskProgress() {
        return taskProgress;
    }

    public void setTaskProgress(String taskProgress) {
        this.taskProgress = taskProgress;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Integer getMbrConditionType() {
        return mbrConditionType;
    }

    public void setMbrConditionType(Integer mbrConditionType) {
        this.mbrConditionType = mbrConditionType;
    }

    public String getMbrCondition() {
        return mbrCondition;
    }

    public void setMbrCondition(String mbrCondition) {
        this.mbrCondition = mbrCondition;
    }

    public String getTemplateCode() {
        return templateCode;
    }

    public void setTemplateCode(String templateCode) {
        this.templateCode = templateCode;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Boolean getIsStoreLimit() {
        return isStoreLimit;
    }

    public void setIsStoreLimit(Boolean isStoreLimit) {
        isStoreLimit = isStoreLimit;
    }

    public String getStoreLimitList() {
        return storeLimitList;
    }

    public void setStoreLimitList(String storeLimitList) {
        this.storeLimitList = storeLimitList;
    }
}

==> mktcenter-service-1.5.2-vg-20220804.104750-29-sources.jar: com/bizvane/mktcenterservice/models/bo/TaskWXBO.java <==
package com.bizvane.mktcenterservice.models.bo;
import org.springframework.format.annotation.DateTimeFormat;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
/**
 * @Author: lijunwei
 * @Time: 2018/8/15 10:20
 */
public class TaskWXBO {
    private  Long taskId;
    private String   taskCode ;
    private String taskName ;
    private Integer  taskType ;
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            locale = "zh",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd"
    )
    private Date startTime;
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            locale = "zh",
            timezone = "GMT+8"
    )
    @DateTimeFormat(
            pattern = "yyyy-MM-dd"
    )
    private Date   endTime;
    private Integer  rewarded;  // 1=已完成  0未完成
    private String  taskProgress; //进度
    private Integer sourceType;//1=线下   2=线上
    private Integer mbrConditionType;
    private String mbrCondition;
    private String templateCode;//问卷调查模板code

    private Long sysCompanyId;

    private Long sysBrandId;

    //门店限制状态：0不限制，1限制
    private Boolean isStoreLimit;

    //白名单店铺list
    private String storeLimitList;

    //memberCode
    private String memberCode;

    public Long getTaskId() {
        return taskId;
    }

    public void setTaskId(Long taskId) {
        this.taskId = taskId;
    }

    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public Integer getTaskType() {
        return taskType;
    }

    public void setTaskType(Integer taskType) {
        this.taskType = taskType;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getRewarded() {
        return rewarded;
    }

    public void setRewarded(Integer rewarded) {
        this.rewarded = rewarded;
    }

    public String getTaskProgress() {
        return taskProgress;
    }

    public void setTaskProgress(String taskProgress) {
        this.taskProgress = taskProgress;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Integer getMbrConditionType() {
        return mbrConditionType;
    }

    public void setMbrConditionType(Integer mbrConditionType) {
        this.mbrConditionType = mbrConditionType;
    }

    public String getMbrCondition() {
        return mbrCondition;
    }

    public void setMbrCondition(String mbrCondition) {
        this.mbrCondition = mbrCondition;
    }

    public String getTemplateCode() {
        return templateCode;
    }

    public void setTemplateCode(String templateCode) {
        this.templateCode = templateCode;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Boolean getIsStoreLimit() {
        return isStoreLimit;
    }

    public void setIsStoreLimit(Boolean isStoreLimit) {
        this.isStoreLimit = isStoreLimit;
    }

    public String getStoreLimitList() {
        return storeLimitList;
    }

    public void setStoreLimitList(String storeLimitList) {
        this.storeLimitList = storeLimitList;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }
}
